# Spectra Manipulator

TODO

Installation Methods
--------------------

* From PyPI:
   * `pip install spectramanipulator`
    

### Used packages

* pyqtgraph
* Lmfit
* matplotlib
* PyQt5
* qtconsole
* numba

First Launch
--------------------

* Run with `python -m spectramanipulator`
* (*optional*) Associate project files (works only for Windows) `python -m spectramanipulator --associate_files`
* (*optional*) Remove association `python -m spectramanipulator --remove_association`